# Generated by Django 4.1.6 on 2023-03-08 08:56

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('df_notifications', '0003_remove_notificationhistory_df_notifica_templat_ec4b48_idx_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='PushActionCategory',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=64, unique=True, verbose_name='id')),
                ('is_active', models.BooleanField(default=True)),
            ],
        ),
        migrations.CreateModel(
            name='PushAction',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=64, unique=True, verbose_name='id')),
                ('sequence', models.IntegerField(default=1000)),
                ('button_text', models.CharField(max_length=64)),
                ('authentication_required', models.BooleanField(default=False)),
                ('destructive', models.BooleanField(default=False)),
                ('foreground', models.BooleanField(default=False)),
                ('category', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='actions', to='df_notifications.pushactioncategory')),
            ],
            options={
                'ordering': ['category', 'sequence'],
            },
        ),
    ]
